.. include:: /ad/ad_attention.inc

.. py:currentmodule:: plasmapy.analysis.swept_langmuir

Swept Langmuir Analysis Module
==============================

.. automodule:: plasmapy.analysis.swept_langmuir

Example Notebooks
-----------------

.. nbgallery::
   :glob:
   :reversed:

   /notebooks/analysis/swept_langmuir/*

API
---

.. automodapi:: plasmapy.analysis.swept_langmuir
   :noindex:
   :no-main-docstring:
   :heading-chars: ^~
